Crate msp430_rt_macros

Attribute Macros

entry
Attribute to declare the entry point of the program
interrupt
Attribute to declare an interrupt handler
pre_init
Attribute to mark which function will be called at the beginning of the reset handler.